===================
VISTA 2.0 Simulator
===================

*VISTA* (Virtual Image Synthesis and Transformation for Autonomy) is a data-driven simulator for training and evaluating full-scale autonomous vehicles. The code in this repository accompanies the following ICRA 2022 submission (under review): **VISTA 2.0: An Open, Data-driven Simulator for Multimodal Sensing and Policy Learning for Autonomous Vehicles**

Features
--------
Coming soon! This repository will be fully released once the above submission is accepted and published!
